@@ -1,4 +1,5 @@
 from __future__ import with_statement
+from cms.api import create_page, create_title
 from cms.models.pagemodel import Page, Placeholder
 from cms.templatetags.cms_tags import (get_site_id, _get_page_by_untyped_arg,
         _show_placeholder_for_page)
@@ -13,6 +14,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpRequest
 from django.template import RequestContext
 from unittest import TestCase
+from django.template.base import Template
 
 
 class TemplatetagTests(TestCase):
@@ -122,3 +124,43 @@ class TemplatetagDatabaseTests(TwoPagesFixture, SettingsOverrideTestCase):
         content = _show_placeholder_for_page(RequestContext(request),
                                             'does_not_exist', 'myreverseid')
         self.assertEqual(content['content'], '')
+
+    def test_untranslated_language_url(self):
+        """ Tests page_language_url templatetag behavior when used on a page
+          without the requested translation, both when CMS_HIDE_UNTRANSLATED is
+          True and False.
+          When True it should return the root page URL if the current page is
+           untranslated (PR #1125)
+
+        """
+        page_1 = create_page('Page 1', 'nav_playground.html', 'en', published=True,
+                             in_navigation=True, reverse_id='page1')
+        create_title("de", "Seite 1", page_1, slug="seite-1")
+        page_2 = create_page('Page 2', 'nav_playground.html', 'en',  page_1, published=True,
+                             in_navigation=True, reverse_id='page2')
+        create_title("de", "Seite 2", page_2, slug="seite-2")
+        page_3 = create_page('Page 3', 'nav_playground.html', 'en',  page_2, published=True,
+                             in_navigation=True, reverse_id='page3')
+        tpl = Template("{% load menu_tags %}{% page_language_url 'de' %}")
+
+        # Default configuration has CMS_HIDE_UNTRANSLATED=False
+        context = self.get_context(page_2.get_absolute_url())
+        context['request'].current_page = page_2
+        res = tpl.render(context)
+        self.assertEqual(res,"/de/seite-2/")
+
+        context = self.get_context(page_3.get_absolute_url())
+        context['request'].current_page = page_3
+        res = tpl.render(context)
+        self.assertEqual(res,"")
+
+        with SettingsOverride(CMS_HIDE_UNTRANSLATED=True):
+            context = self.get_context(page_2.get_absolute_url())
+            context['request'].current_page = page_2
+            res = tpl.render(context)
+            self.assertEqual(res,"/de/seite-2/")
+
+            context = self.get_context(page_3.get_absolute_url())
+            context['request'].current_page = page_3
+            res = tpl.render(context)
+            self.assertEqual(res,"/de/")
